@@ -36,6 +36,7 @@ kMBIO_RAZCONFIG=20
 kMBIO_BEEP=21
 kMBIO_NETSCAN=22
 kMBIO_IOMAPPING=23
+kMBIO_IOUPDATEDESCRIPTION=24
 
 # kST_DUPLICATERSRC=98
 
@@ -232,6 +233,7 @@ class MBIOLink(object):
         self.packetManager.addHandler(kLP_MBIO, kMBIO_AUTH, self.onAuth)
         self.packetManager.addHandler(kLP_MBIO, kMBIO_BADAUTH, self.onBadAuth)
         self.packetManager.addHandler(kLP_MBIO, kMBIO_IOMAPPING, self.onIoMapping)
+        self.packetManager.addHandler(kLP_MBIO, kMBIO_IOUPDATEDESCRIPTION, self.onIoUpdateDescription)
 
     def ping(self):
         if self._connected:
@@ -417,6 +419,31 @@ class MBIOLink(object):
             value.config.set('iomapitem', item)
             value.config.set('iomapkey', 'r_%u_%u_mbio_%d_0' % (installation, station, item))
 
+    def onIoUpdateDescription(self, up):
+        key=up.readStr()
+        value=self._mbio.value(key)
+        description=up.readStr()
+        if value is not None:
+            try:
+                if value.description.lower()==description.lower():
+                    return
+            except:
+                pass
+
+            try:
+                data=description.split('|')
+                label=data[0]
+
+                if label.lower()==value.key:
+                    return
+
+                # TODO: We may here extract low/normal/high states
+
+                self.logger.warning('<IOUPDATEDESCRIPTION %s [%s]' % (key, label))
+                value.config.set('iodescription', label.strip())
+            except:
+                pass
+
     # def onReadItemResponse(self, up):
         # pid=up.readWord()
         # index=up.readWord()
