@@ -93,6 +93,9 @@ class MBIO(object):
         except:
             pass
 
+    def microsleep(self):
+        time.sleep(0)
+
     def getVersion(self):
         """Return the version of the module"""
         try:
@@ -667,7 +670,11 @@ class MBIO(object):
     def values(self, key='*', sort=True):
         """Return the MBIOValues given by it's key using value.match() """
         values=[]
+        count=0
         for value in self._valuesByKey.values():
+            count+=1
+            if count % 32 == 0:
+                self.microsleep()
             if value.match(key):
                 values.append(value)
         if sort:
