@@ -166,6 +166,10 @@ class MBIOValue(object):
     def tag(self):
         return self.config.iomaptag
 
+    @property
+    def description(self):
+        return self.config.iodescription
+
     def keyparts(self, part=None):
         try:
             parts=self.key.split('_')
