@@ -272,6 +272,7 @@ class MBIOWsMonitor(MBIOTask):
             item['digital']=v.isDigital()
             item['enable']=v.isEnabled()
             item['manual']=v.isManual()
+            item['description']=v.description
             items.append(item)
 
         data={'data': items}
@@ -590,8 +591,8 @@ class MBIOWsMonitor(MBIOTask):
                             <th>Flags</th>
                             <th>Age</th>
                             <th>Error</th>
-                            <th>Class</th>
                             <th>Tag</th>
+                            <th>Label</th>
                         </tr>
                     </thead>
                     </table>
@@ -666,8 +667,8 @@ class MBIOWsMonitor(MBIOTask):
                         { data: "flags" },
                         { data: "age", render: v=>v<3600 ? v : '' },
                         { data: "error" },
-                        { data: "class" },
-                        { data: "tag" }
+                        { data: "tag" },
+                        { data: "description" }
                     ],
 
                     rowCallback: function (row, data) {
